@@ -1,10 +1,10 @@
 #ifndef __GRAD
 #define __GRAD 1
 
-#include "common.h"
+#include "types.h"
 
 typedef struct _ImlibRangeColor {
-   DATA8               red, green, blue, alpha;
+   uint8_t             red, green, blue, alpha;
    int                 distance;
    struct _ImlibRangeColor *next;
 } ImlibRangeColor;
@@ -15,8 +15,8 @@ typedef struct {
 
 ImlibRange         *__imlib_CreateRange(void);
 void                __imlib_FreeRange(ImlibRange * rg);
-void                __imlib_AddRangeColor(ImlibRange * rg, DATA8 r, DATA8 g,
-                                          DATA8 b, DATA8 a, int dist);
+void                __imlib_AddRangeColor(ImlibRange * rg, uint8_t r, uint8_t g,
+                                          uint8_t b, uint8_t a, int dist);
 void                __imlib_DrawGradient(ImlibImage * im,
                                          int x, int y, int w, int h,
                                          ImlibRange * rg, double angle,
